@@ -23,6 +23,7 @@ from stevedore import driver as stevedore_driver
 from octavia_lib.api.drivers import data_models as driver_dm
 from octavia_lib.api.drivers import exceptions
 from octavia_lib.api.drivers import provider_base as driver_base
+from octavia_lib.common import constants as lib_consts
 
 from octavia.api.drivers.amphora_driver import flavor_schema
 from octavia.api.drivers import utils as driver_utils
@@ -68,6 +69,13 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
                                           project_id=project_id, vip=vip_obj)
 
         network_driver = utils.get_network_driver()
+        vip_network = network_driver.get_network(
+            vip_dictionary[lib_consts.VIP_NETWORK_ID])
+        if not vip_network.port_security_enabled:
+            message = "Port security must be enabled on the VIP network."
+            raise exceptions.DriverError(user_fault_string=message,
+                                         operator_fault_string=message)
+
         try:
             vip = network_driver.allocate_vip(lb_obj)
         except network_base.AllocateVIPException as e:
@@ -164,16 +172,16 @@ class AmphoraProviderDriver(driver_base.ProviderDriver):
             pool_dict['enabled'] = pool_dict.pop('admin_state_up')
         pool_id = pool_dict.pop('pool_id')
         if 'tls_container_ref' in pool_dict:
-            pool_dict['tls_container_id'] = pool_dict.pop('tls_container_ref')
+            pool_dict['tls_certificate_id'] = pool_dict.pop(
+                'tls_container_ref')
         pool_dict.pop('tls_container_data', None)
         if 'ca_tls_container_ref' in pool_dict:
             pool_dict['ca_tls_certificate_id'] = pool_dict.pop(
                 'ca_tls_container_ref')
         pool_dict.pop('ca_tls_container_data', None)
-        if 'client_crl_container_ref' in pool_dict:
-            pool_dict['client_crl_container_id'] = pool_dict.pop(
-                'client_crl_container_ref')
-        pool_dict.pop('client_crl_container_data', None)
+        if 'crl_container_ref' in pool_dict:
+            pool_dict['crl_container_id'] = pool_dict.pop('crl_container_ref')
+        pool_dict.pop('crl_container_data', None)
 
         payload = {consts.POOL_ID: pool_id,
                    consts.POOL_UPDATES: pool_dict}
