@@ -12,9 +12,10 @@
 
 """Policy Engine For Octavia."""
 
-import logging
+import sys
 
 from oslo_config import cfg
+from oslo_log import log as logging
 from oslo_policy import policy as oslo_policy
 from oslo_utils import excutils
 
@@ -103,7 +104,8 @@ class Policy(oslo_policy.Enforcer):
         credentials = context.to_policy_values()
         # Inject is_admin into the credentials to allow override via
         # config auth_strategy = constants.NOAUTH
-        credentials['is_admin'] = context.is_admin
+        credentials['is_admin'] = (
+            credentials.get('is_admin') or context.is_admin)
 
         if not exc:
             exc = exceptions.PolicyForbidden
@@ -151,5 +153,14 @@ class IsAdminCheck(oslo_policy.Check):
 
 # This is used for the oslopolicy-policy-generator tool
 def get_no_context_enforcer():
-    config.init([])
+
+    # oslo.config needs access to the --config-dir and --config-file
+    # command line args
+    filtered_args = ['--config-dir', '--config-file']
+    # Start at 1 because cfg.CONF expects the equivalent of sys.argv[1:]
+    conf_args = [arg for idx, arg in enumerate(sys.argv[1:])
+                 if (arg in filtered_args or
+                     sys.argv[idx] in filtered_args)]
+
+    config.init(conf_args)
     return Policy()
