@@ -126,6 +126,11 @@ CFG_FILE_TEMPLATE_v6 = (
     "    # Member %(member_id4)s is disabled\n\n"
     "}")
 
+CFG_FILE_TEMPLATE_DISABLED_LISTENER = (
+    "# Listener %(listener_id)s is disabled \n\n"
+    "net_namespace %(ns_name)s\n\n"
+)
+
 IPVSADM_OUTPUT_TEMPLATE = (
     "IP Virtual Server version 1.2.1 (size=4096)\n"
     "Prot LocalAddress:Port Scheduler Flags\n"
@@ -162,6 +167,7 @@ class LvsQueryTestCase(base.TestCase):
         self.member_id2_v6 = uuidutils.generate_uuid()
         self.member_id3_v6 = uuidutils.generate_uuid()
         self.member_id4_v6 = uuidutils.generate_uuid()
+        self.disabled_listener_id = uuidutils.generate_uuid()
         cfg_content_v4 = CFG_FILE_TEMPLATE_v4 % {
             'listener_id': self.listener_id_v4,
             'ns_name': constants.AMPHORA_NAMESPACE,
@@ -180,10 +186,19 @@ class LvsQueryTestCase(base.TestCase):
             'member_id3': self.member_id3_v6,
             'member_id4': self.member_id4_v6
         }
+        cfg_content_disabled_listener = (
+            CFG_FILE_TEMPLATE_DISABLED_LISTENER % {
+                'listener_id': self.listener_id_v6,
+                'ns_name': constants.AMPHORA_NAMESPACE,
+            }
+        )
         self.useFixture(test_utils.OpenFixture(
             util.keepalived_lvs_cfg_path(self.listener_id_v4), cfg_content_v4))
         self.useFixture(test_utils.OpenFixture(
             util.keepalived_lvs_cfg_path(self.listener_id_v6), cfg_content_v6))
+        self.useFixture(test_utils.OpenFixture(
+            util.keepalived_lvs_cfg_path(self.disabled_listener_id),
+            cfg_content_disabled_listener))
 
     @mock.patch('subprocess.check_output')
     def test_get_listener_realserver_mapping(self, mock_check_output):
@@ -278,8 +293,20 @@ class LvsQueryTestCase(base.TestCase):
                  'ipport': None}]}
         self.assertEqual((expected, constants.AMPHORA_NAMESPACE), res)
 
+        # disabled
+        res = lvs_query.get_udp_listener_resource_ipports_nsname(
+            self.disabled_listener_id)
+        self.assertEqual((None, constants.AMPHORA_NAMESPACE), res)
+
+    @mock.patch('os.stat')
     @mock.patch('subprocess.check_output')
-    def test_get_udp_listener_pool_status(self, mock_check_output):
+    def test_get_udp_listener_pool_status(self, mock_check_output,
+                                          mock_os_stat):
+        mock_os_stat.side_effect = (
+            mock.Mock(st_mtime=1234),
+            mock.Mock(st_mtime=1234),
+        )
+
         # test with ipv4 and ipv6
         mock_check_output.return_value = KERNAL_FILE_SAMPLE_V4
         res = lvs_query.get_udp_listener_pool_status(self.listener_id_v4)
@@ -293,6 +320,11 @@ class LvsQueryTestCase(base.TestCase):
                          self.member_id4_v4: constants.MAINT}}}
         self.assertEqual(expected, res)
 
+        mock_os_stat.side_effect = (
+            mock.Mock(st_mtime=1234),
+            mock.Mock(st_mtime=1234),
+        )
+
         mock_check_output.return_value = KERNAL_FILE_SAMPLE_V6
         res = lvs_query.get_udp_listener_pool_status(self.listener_id_v6)
         expected = {
@@ -305,6 +337,28 @@ class LvsQueryTestCase(base.TestCase):
                          self.member_id4_v6: constants.MAINT}}}
         self.assertEqual(expected, res)
 
+    @mock.patch('os.stat')
+    @mock.patch('subprocess.check_output')
+    def test_get_udp_listener_pool_status_restarting(self, mock_check_output,
+                                                     mock_os_stat):
+        mock_os_stat.side_effect = (
+            mock.Mock(st_mtime=1234),  # config file
+            mock.Mock(st_mtime=1220),  # pid file
+        )
+
+        # test with ipv4 and ipv6
+        mock_check_output.return_value = KERNAL_FILE_SAMPLE_V4
+        res = lvs_query.get_udp_listener_pool_status(self.listener_id_v4)
+        expected = {
+            'lvs':
+            {'uuid': self.pool_id_v4,
+             'status': constants.UP,
+             'members': {self.member_id1_v4: constants.UP,
+                         self.member_id2_v4: constants.UP,
+                         self.member_id3_v4: constants.RESTARTING,
+                         self.member_id4_v4: constants.MAINT}}}
+        self.assertEqual(expected, res)
+
     @mock.patch('octavia.amphorae.backends.utils.keepalivedlvs_query.'
                 'get_udp_listener_resource_ipports_nsname')
     def test_get_udp_listener_pool_status_when_no_pool(
@@ -331,7 +385,7 @@ class LvsQueryTestCase(base.TestCase):
         # the returned resource_ipport_mapping doesn't contains the 'Members'
         # resources, that means the pool of listener doesn't have a enabled
         # pool resource, so the pool is not usable, then the pool status will
-        # return DOWN.
+        # return UP.
         mock_get_resource_ipports.return_value = (
             {
                 'Listener': {'id': self.listener_id_v4,
@@ -341,19 +395,24 @@ class LvsQueryTestCase(base.TestCase):
         res = lvs_query.get_udp_listener_pool_status(self.listener_id_v4)
         expected = {'lvs': {
             'uuid': self.pool_id_v4,
-            'status': constants.DOWN,
+            'status': constants.UP,
             'members': {}
         }}
         self.assertEqual(expected, res)
 
+    @mock.patch('os.stat')
     @mock.patch('octavia.amphorae.backends.utils.keepalivedlvs_query.'
                 'get_listener_realserver_mapping')
     def test_get_udp_listener_pool_status_when_not_get_realserver_result(
-            self, mock_get_mapping):
+            self, mock_get_mapping, mock_os_stat):
         # This will hit if the kernel lvs file (/proc/net/ip_vs)
         # lose its content. So at this moment, eventhough we configure the
         # pool and member into udp keepalived config file, we have to set
         # ths status of pool and its members to DOWN.
+        mock_os_stat.side_effect = (
+            mock.Mock(st_mtime=1234),
+            mock.Mock(st_mtime=1234),
+        )
         mock_get_mapping.return_value = (False, {})
         res = lvs_query.get_udp_listener_pool_status(self.listener_id_v4)
         expected = {
@@ -456,3 +515,14 @@ class LvsQueryTestCase(base.TestCase):
         mock_is_running.return_value = False
         res = lvs_query.get_udp_listeners_stats()
         self.assertEqual({}, res)
+
+    @mock.patch('subprocess.check_output')
+    @mock.patch("octavia.amphorae.backends.agent.api_server.util."
+                "is_udp_listener_running", return_value=True)
+    @mock.patch("octavia.amphorae.backends.agent.api_server.util."
+                "get_udp_listeners")
+    def test_get_udp_listeners_stats_disabled_listener(
+            self, mock_get_listener, mock_is_running, mock_check_output):
+        mock_get_listener.return_value = [self.disabled_listener_id]
+        res = lvs_query.get_udp_listeners_stats()
+        self.assertEqual({}, res)
