@@ -43,6 +43,21 @@ class TestAmphoraDriver(base.TestRpc):
 
         self.assertEqual(self.sample_data.provider_vip_dict, provider_vip_dict)
 
+    @mock.patch('octavia.common.utils.get_network_driver')
+    def test_create_vip_port_without_port_security_enabled(
+            self, mock_get_net_driver):
+        mock_net_driver = mock.MagicMock()
+        mock_get_net_driver.return_value = mock_net_driver
+        network = mock.MagicMock()
+        network.port_security_enabled = False
+        mock_net_driver.get_network.return_value = network
+        mock_net_driver.allocate_vip.return_value = self.sample_data.db_vip
+
+        self.assertRaises(exceptions.DriverError,
+                          self.amp_driver.create_vip_port,
+                          self.sample_data.lb_id, self.sample_data.project_id,
+                          self.sample_data.provider_vip_dict)
+
     @mock.patch('octavia.common.utils.get_network_driver')
     def test_create_vip_port_failed(self, mock_get_net_driver):
         mock_net_driver = mock.MagicMock()
@@ -195,8 +210,19 @@ class TestAmphoraDriver(base.TestRpc):
         old_provider_pool = driver_dm.Pool(
             pool_id=self.sample_data.pool1_id)
         provider_pool = driver_dm.Pool(
-            pool_id=self.sample_data.pool1_id, admin_state_up=True)
-        pool_dict = {'enabled': True}
+            pool_id=self.sample_data.pool1_id, admin_state_up=True,
+            ca_tls_container_data='CA DATA', ca_tls_container_ref='CA REF',
+            crl_container_data='CRL DATA', crl_container_ref='CRL REF',
+            description='TEST DESCRIPTION', name='TEST NAME',
+            lb_algorithm=consts.LB_ALGORITHM_SOURCE_IP,
+            session_persistence='FAKE SP', tls_container_data='TLS DATA',
+            tls_container_ref='TLS REF', tls_enabled=False)
+        pool_dict = {'description': 'TEST DESCRIPTION',
+                     'lb_algorithm': 'SOURCE_IP', 'name': 'TEST NAME',
+                     'session_persistence': 'FAKE SP', 'tls_enabled': False,
+                     'enabled': True, 'tls_certificate_id': 'TLS REF',
+                     'ca_tls_certificate_id': 'CA REF',
+                     'crl_container_id': 'CRL REF'}
         self.amp_driver.pool_update(old_provider_pool, provider_pool)
         payload = {consts.POOL_ID: self.sample_data.pool1_id,
                    consts.POOL_UPDATES: pool_dict}
