@@ -51,8 +51,15 @@ def generate(flow_list, output_directory):
                                     current_tuple[1])
             current_instance = current_class()
             get_flow_method = getattr(current_instance, current_tuple[2])
-            if (current_tuple[1] == 'LoadBalancerFlows' and
-                    current_tuple[2] == 'get_create_load_balancer_flow'):
+            if (current_tuple[1] == 'AmphoraFlows' and
+                    current_tuple[2] == 'get_failover_amphora_flow'):
+                amp1 = dmh.generate_amphora()
+                amp2 = dmh.generate_amphora()
+                lb = dmh.generate_load_balancer(amphorae=[amp1, amp2])
+                current_engine = engines.load(
+                    get_flow_method(amp1, 2))
+            elif (current_tuple[1] == 'LoadBalancerFlows' and
+                  current_tuple[2] == 'get_create_load_balancer_flow'):
                 current_engine = engines.load(
                     get_flow_method(
                         constants.TOPOLOGY_ACTIVE_STANDBY))
@@ -66,6 +73,19 @@ def generate(flow_list, output_directory):
                 lb = dmh.generate_load_balancer()
                 delete_flow, store = get_flow_method(lb)
                 current_engine = engines.load(delete_flow)
+            elif (current_tuple[1] == 'LoadBalancerFlows' and
+                    current_tuple[2] == 'get_failover_LB_flow'):
+                amp1 = dmh.generate_amphora()
+                amp2 = dmh.generate_amphora()
+                lb = dmh.generate_load_balancer(
+                    amphorae=[amp1, amp2],
+                    topology=constants.TOPOLOGY_ACTIVE_STANDBY)
+                current_engine = engines.load(
+                    get_flow_method([amp1, amp2], lb))
+            elif (current_tuple[1] == 'MemberFlows' and
+                  current_tuple[2] == 'get_batch_update_members_flow'):
+                current_engine = engines.load(
+                    get_flow_method([], [], []))
             else:
                 current_engine = engines.load(get_flow_method())
             current_engine.compile()
@@ -90,12 +110,20 @@ def generate(flow_list, output_directory):
             current_doc_file.write(doc_tuple[1] + '\n')
             current_doc_file.write('-' * len(doc_tuple[1]) + '\n')
             current_doc_file.write('\n')
-            current_doc_file.write('.. image:: ' + doc_tuple[0] +
+            current_doc_file.write('.. only:: html\n')
+            current_doc_file.write('\n')
+            current_doc_file.write('   .. image:: ' + doc_tuple[0] +
                                    '-' + doc_tuple[1] + '.svg\n')
-            current_doc_file.write('    :width: 660px\n')
-            current_doc_file.write('    :target: ../../_images/' +
+            current_doc_file.write('       :width: 660px\n')
+            current_doc_file.write('       :target: ../../../_images/' +
                                    doc_tuple[0] +
                                    '-' + doc_tuple[1] + '.svg\n')
+            current_doc_file.write('\n')
+            current_doc_file.write('.. only:: latex\n')
+            current_doc_file.write('\n')
+            current_doc_file.write('   .. image:: ' + doc_tuple[0] +
+                                   '-' + doc_tuple[1] + '.svg\n')
+            current_doc_file.write('       :width: 660px\n')
 
         # First or new class, create the file
         else:
@@ -116,17 +144,27 @@ def generate(flow_list, output_directory):
             current_doc_file.write('   :depth: 2\n')
             current_doc_file.write('   :backlinks: top\n')
             current_doc_file.write('\n')
-            current_doc_file.write('Click on any flow to view full size.\n')
+            current_doc_file.write('.. only:: html\n')
+            current_doc_file.write('\n')
+            current_doc_file.write('   Click on any flow to view full size.\n')
             current_doc_file.write('\n')
             current_doc_file.write(doc_tuple[1] + '\n')
             current_doc_file.write('-' * len(doc_tuple[1]) + '\n')
             current_doc_file.write('\n')
-            current_doc_file.write('.. image:: ' + doc_tuple[0] +
+            current_doc_file.write('.. only:: html\n')
+            current_doc_file.write('\n')
+            current_doc_file.write('   .. image:: ' + doc_tuple[0] +
                                    '-' + doc_tuple[1] + '.svg\n')
-            current_doc_file.write('    :width: 660px\n')
-            current_doc_file.write('    :target: ../../_images/' +
+            current_doc_file.write('       :width: 660px\n')
+            current_doc_file.write('       :target: ../../../_images/' +
                                    doc_tuple[0] +
                                    '-' + doc_tuple[1] + '.svg\n')
+            current_doc_file.write('\n')
+            current_doc_file.write('.. only:: latex\n')
+            current_doc_file.write('\n')
+            current_doc_file.write('   .. image:: ' + doc_tuple[0] +
+                                   '-' + doc_tuple[1] + '.svg\n')
+            current_doc_file.write('       :width: 660px\n')
 
     current_doc_file.close()
 
@@ -134,5 +172,6 @@ def generate(flow_list, output_directory):
 def getDiagKey(item):
     return item[0] + '-' + item[1]
 
+
 if __name__ == "__main__":
     main()
